@@ -13,8 +13,9 @@
 #include <KLocalizedString>
 #include <QApplication>
 #include <QCommandLineParser>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <kdelibs4configmigrator.h>
-
+#endif
 int main(int argc, char **argv)
 {
     // Fixes blurry icons with fractional scaling
@@ -22,11 +23,12 @@ int main(int argc, char **argv)
     QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
 #endif
     QApplication app(argc, argv);
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Kdelibs4ConfigMigrator migrate(QStringLiteral("kapman"));
     migrate.setConfigFiles(QStringList() << QStringLiteral("kapmanrc"));
     migrate.setUiFiles(QStringList() << QStringLiteral("kapmanui.rc"));
     migrate.migrate();
+#endif
     KLocalizedString::setApplicationDomain("kapman");
     // About Kapman
     KAboutData about(QStringLiteral("kapman"),
@@ -34,7 +36,9 @@ int main(int argc, char **argv)
                      QStringLiteral(KAPMAN_VERSION_STRING),
                      i18n("Kapman: Go through the levels escaping ghosts!"),
                      KAboutLicense::GPL,
-                     i18n("Copyright (c) 2007-2008 The KapTeam"));
+                     i18n("Copyright (c) 2007-2008 The KapTeam"),
+                     QString(),
+                     QStringLiteral("https://apps.kde.org/kapman"));
     // Alphabetical order of Developers of Kapman
     about.addAuthor(i18n("Alexandre Galinier"), i18n("Developer"), QStringLiteral("alex.galinier@gmail.com"));
     about.addAuthor(i18n("Nathalie Liesse"), i18n("Developer"), QStringLiteral("nathalie.liesse@gmail.com"));
@@ -43,7 +47,6 @@ int main(int argc, char **argv)
     about.addAuthor(i18n("Romain Castan"), i18n("Developer"), QStringLiteral("romaincastan@gmail.com"));
     about.addAuthor(i18n("Thomas Gallinari"), i18n("Developer"), QStringLiteral("tg8187@yahoo.fr"));
     about.addCredit(i18n("Roney Gomes"), i18n("Port to KgSound framework"), QStringLiteral("roney477@gmail.com"));
-    about.setHomepage(QStringLiteral("https://www.kde.org/applications/games/kapman/"));
 
     // Command line arguments
     QCommandLineParser parser;
